package com.app.ui.adapter

import android.animation.ObjectAnimator
import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Color
import android.support.v4.app.FragmentManager
import android.view.View
import android.view.ViewGroup
import android.view.animation.AlphaAnimation
import android.widget.BaseAdapter
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.business.YYDataPool
import com.app.constants.KeyConstants
import com.app.model.UserBase
import com.app.model.VideoGirlUser
import com.app.model.request.SponsorVideoRequest
import com.app.model.response.SponsorVideoResponse
import com.app.ui.YYBaseActivity
import com.app.ui.activity.HomeActivity
import com.app.util.SponsorVideoHelper
import com.app.util.Tools
import com.app.util.cache.YYPreferences
import com.app.widget.dialog.SceneSelectionDialog
import com.sp.util.YYPreferenceSP
import com.yy.util.BaseTools
import com.yy.util.image.VolleyUtil
import com.yy.util.net.NewHttpResponeCallBack
import com.yy.util.string.StringUtils

/**
 * Created by liujiawei on 2017/8/1.
 */
class PopularAdapterPl(var activity: HomeActivity, var fragmentManager: FragmentManager) : BaseAdapter() {

    private var mData: MutableList<VideoGirlUser> = mutableListOf()
    private var yyDataPool: YYDataPool? = null


    init {
        yyDataPool = YYDataPool.getInstance(YYApplication.getInstance())
    }

    interface ItemOnclick {
        fun onClick(userBase: UserBase?, position: Int, i: Int)
    }

    lateinit var itemOnclick: ItemOnclick
    fun setOnItemOnClick(itemOnclick: ItemOnclick) {
        this.itemOnclick = itemOnclick
    }

    override fun getView(position: Int, convertView: View?, parent: ViewGroup): View {
        var rootView: LinearLayout? = null
        try {
            val viewHolder = PopularViewHolder.newInstance(activity, convertView)
            rootView = viewHolder.rootView
            viewHolder.bindView(mData[position], position, itemOnclick)
            return rootView
        } catch (x: Exception) {
            x.toString()
        }
        return rootView!!
    }

    override fun getItem(position: Int): Any {
        return mData[position]
    }

    override fun getItemId(position: Int): Long {
        return position.toLong()
    }

    override fun getCount(): Int {
        return mData.size
    }

    fun setData(listUser: MutableList<VideoGirlUser>) {
        mData.addAll(listUser)
    }

    fun clearData() {
        mData.clear()
    }

    /**
     * 视频邀请
     * @param userBase
     */
    fun videoInvitation(userBase: UserBase, src: Int) {
        if (YYPreferences.getInstance().getBoolean(YYPreferences.TAG_DEFAUT_SETTING, false) || src == SponsorVideoRequest.SRC_RECOMMENT_VOICE_CHAT) {// 读取默认设置状态
            var isShowFace = false
            val configInfo = YYApplication.getInstance().configInfo
            if (configInfo != null) {
                val otherCfg = configInfo.otherCfg
                if (otherCfg != null) {
                    if (otherCfg.isLeakingFacee == 1) {
                        isShowFace = true
                    }
                }
            }
            loadVideoPlugin(isShowFace, userBase, src)
        } else if (fragmentManager != null) {
            val dialog = SceneSelectionDialog().newInstance()
            dialog.show(fragmentManager, "dialog")
            dialog.setOnFinishListener { isShowFace, isDefautItme ->
                val configInfo = YYApplication.getInstance().configInfo
                if (configInfo != null) {
                    val otherCfg = configInfo.otherCfg
                    if (otherCfg != null) {
                        otherCfg.isLeakingFacee = if (isShowFace) 1 else 0
                        configInfo.otherCfg = otherCfg
                    }
                }
                YYPreferences.getInstance().putBoolean(YYPreferences.TAG_DEFAUT_SETTING, isDefautItme)
                loadVideoPlugin(isShowFace, userBase, src)
            }
        }
    }

    /**
     * 加载视频插件
     * @param isShowFace 是否露脸
     * *
     * @param userBase
     */
    private fun loadVideoPlugin(isShowFace: Boolean, userBase: UserBase?, src: Int) {

        if (userBase == null || activity == null) {
            return
        }

//        if (Tools.isAvailable(YYApplication.getInstance(), YYApplication.getInstance().VIDEO_APP_PACKAGE_NAME)) {
        val type = if (!Tools.isAvailable(YYApplication.getInstance(), YYApplication.getInstance().VIDEO_APP_PACKAGE_NAME)) 1 else 0
        val request = SponsorVideoRequest(userBase.id, YYPreferences.getInstance().userId, if (isShowFace) 1 else 0, src, type)
        RequestApiData.getInstance().sponsorVideo(request, SponsorVideoResponse::class.java, object : NewHttpResponeCallBack {
            override fun onResponeStart(apiName: String) {
                if (InterfaceUrlConstants.URL_SPONSORVIDEO == apiName) {
                    activity.showLoadingDialog("正在邀请...")
                }
            }

            override fun onLoading(apiName: String, count: Long, current: Long) {

            }

            override fun onSuccess(apiName: String, `object`: Any) {
                if (InterfaceUrlConstants.URL_SPONSORVIDEO == apiName) {
                    if (`object` is SponsorVideoResponse) {
                        val response = `object`
                        val state = response.state
                        YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_STATE, state)
                        if (state == 0 || state == 5) {// 可以连通
                            val usableTime = response.usableTime
                            val videoId = response.videoId
                            val noPwdState = response.noPwdState
                            val continueBuyUrl = response.continueBuyUrl
                            YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_ID, videoId)

                            val url = response.url
                            YYPreferenceSP.getInstance().putString(KeyConstants.KEY_VIDEO_STATE_URL, if (state == 5) url else "")

                            if (userBase != null) {
                                val image = userBase.image
                                var imgUrl = ""
                                if (image != null) {
                                    imgUrl = image.imageUrl
                                }
                                YYApplication.getInstance().startVideoApp(
                                        YYPreferences.getInstance().userId,
                                        userBase.id,
                                        userBase.nickName,
                                        imgUrl,
                                        YYPreferences.getInstance().gender,
                                        usableTime,
                                        isShowFace,
                                        0, 0, noPwdState, continueBuyUrl,
                                        if (activity != null) activity.supportFragmentManager else null)

                            }
                        } else if (state == 6) {
                            val usableTime = response.usableTime
                            val noPwdState = response.noPwdState
                            val continueBuyUrl = response.continueBuyUrl
                            val videoId = response.videoId
                            YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_ID, videoId)

                            if (userBase != null) {
                                val image = userBase.image
                                var imgUrl = ""
                                if (image != null) {
                                    imgUrl = image.imageUrl
                                }
                                YYApplication.getInstance().startVoiceApp(
                                        YYPreferences.getInstance().userId,
                                        userBase.id,
                                        userBase.nickName,
                                        imgUrl,
                                        YYPreferences.getInstance().gender,
                                        usableTime,
                                        0,
                                        noPwdState,
                                        continueBuyUrl,
                                        if (activity != null) activity.supportFragmentManager else null
                                )
                            }

                        } else if (state == 1) {// 跳付费页面
                            val url = response.url
                            activity.showVideoPalPayActivity(url)
                        } else if (state == 2) {// 占线
                            val msg = response.msg
                            Tools.showToast(msg, 3000)
                        } else if (state == 3) {// 占线
                            val msg = response.msg
                            Tools.showToast(msg, 3000)
                        }

                        if (state != 1) {
                            activity.dismissLoadingDialog()
                        }
                    }
                }
            }

            override fun onFailure(apiName: String, t: Throwable?, errorNo: Int, strMsg: String?) {
                Tools.showToast(strMsg)
                activity.dismissLoadingDialog()
            }
        })
    }

    class PopularViewHolder {

        fun bindView(videoGirlUser: VideoGirlUser?, position: Int, itemOnclick: ItemOnclick) {
            var viewGroup = rootView.getChildAt(0) as ViewGroup

            var tag0 = viewGroup.getChildAt(0).tag
            if (tag0 != null && tag0 is ItemHolder && videoGirlUser != null) {
                viewGroup.getChildAt(0)?.setOnClickListener {
                    itemOnclick?.onClick(videoGirlUser?.userBase, position, 0)
                }

                var itemHolder = tag0
                itemHolder.bindItemView(videoGirlUser, position)
            }
//            val tag1 = viewGroup.getChildAt(1).tag
//            if (tag1 != null && tag1 is ItemHolder && videoGirlUser2 != null) {
//                viewGroup.getChildAt(1)?.setOnClickListener {
//                    itemOnclick?.onClick(videoGirlUser2?.userBase, position, 1)
//                }
//                var itemHolder = tag1
//                itemHolder.bindItemView(videoGirlUser2, position)
//            }
        }

        companion object {
            fun newInstance(context: Context, convertView: View?): PopularViewHolder {
                if (convertView != null && convertView.tag != null && convertView.tag is PopularViewHolder) {
                    return convertView.tag as PopularViewHolder
                }
                return PopularViewHolder(context)
            }
        }


        var rootView: LinearLayout

        constructor(context: Context) {
            rootView = LinearLayout(context)
            rootView.setPadding(BaseTools.dp2px(9f), 0, BaseTools.dp2px(9f), 0)
            rootView.orientation = LinearLayout.VERTICAL

            var itemLayout = LinearLayout(context)
            itemLayout.orientation = LinearLayout.HORIZONTAL

            var item0 = ItemHolder(context)
            var itemView0 = item0.getRootView()
            var lp0 = LinearLayout.LayoutParams(0, LinearLayout.LayoutParams.WRAP_CONTENT, 1f)
            lp0.leftMargin = 0
            lp0.topMargin = BaseTools.dp2px(4.5f)
            lp0.rightMargin = BaseTools.dp2px(4.5f)
            lp0.bottomMargin = BaseTools.dp2px(4.5f)
            itemView0?.layoutParams = lp0
            itemLayout.addView(itemView0)

            // 注释此处表示只显示一列
//            var item1 = ItemHolder(context)
//            var itemView1 = item1.getRootView()
//            var lp1 = LinearLayout.LayoutParams(0, LinearLayout.LayoutParams.WRAP_CONTENT, 1f)
//            lp1.leftMargin = BaseTools.dp2px(4.5f)
//            lp1.topMargin = BaseTools.dp2px(4.5f)
//            lp1.rightMargin = 0
//            lp1.bottomMargin = BaseTools.dp2px(4.5f)
//            itemView1?.layoutParams = lp1
//            itemLayout.addView(itemView1)

            rootView.addView(itemLayout)
            rootView.tag = this
        }

    }

    class ItemHolder(c: Context) {
        var headphoto: ImageView? = null
        var nickname: TextView? = null
        var age: TextView? = null
        //        var height: TextView? = null
//        var distance: ImageView? = null
        var hobby: TextView? = null
        var chracter: TextView? = null
        //        var chatState: TextView? = null
//        var ivAuth: ImageView? = null
        var view: View? = null
        var fraToVoice: View? = null
        var linOnlineState: View? = null
        var ivOnlineState: View? = null
        var tvOnlineState: TextView? = null
        //        var gifView: GifImageView?=null
        private var defaultBitmap: Bitmap? = null
        private var yyDataPool: YYDataPool? = null
        var context: YYBaseActivity
        private var mAnimMap = mutableMapOf<Int, ObjectAnimator>()

        init {
            yyDataPool = YYDataPool.getInstance(YYApplication.getInstance())
            defaultBitmap = BitmapFactory.decodeResource(YYApplication.getInstance().resources, R.drawable.radio_women_default_bg)
            view = View.inflate(YYApplication.getInstance(), R.layout.adapter_popular_item_pl2, null)
            headphoto = view?.findViewById(R.id.iv_nearby_person_item_headphoto)
            nickname = view?.findViewById(R.id.tv_nearby_person_item_nickname)
//            ivAuth = view?.findViewById(R.id.iv_auth)
//            distance = view?.findViewById(R.id.tv_nearby_person_item_distance)
            age = view?.findViewById(R.id.tv_nearby_person_item_age)
//            height = view?.findViewById(R.id.tv_nearby_person_item_height)
            hobby = view?.findViewById(R.id.tv_nearby_person_item_hobby)
            chracter = view?.findViewById(R.id.tv_nearby_person_item_chracter)
//            chatState = view?.findViewById(R.id.tv_nearby_person_item_chat_state)
            fraToVoice = view?.findViewById(R.id.fra_to_voice)
            linOnlineState = view?.findViewById(R.id.linOnlineState)
            ivOnlineState = view?.findViewById(R.id.ivOnlineState)
            tvOnlineState = view?.findViewById(R.id.tvOnlineState)
//            gifView = view?.findViewById(R.id.gifView)
//            with(gifView?.drawable as GifDrawable) {
//                loopCount = 65535
//            }

            view?.tag = this
            context = c as YYBaseActivity
        }

        fun getRootView(): View? {
            return view
        }

        @SuppressLint("SetTextI18n")
        fun bindItemView(videoGirlUser: VideoGirlUser?, position: Int) {
            var userBase = videoGirlUser?.userBase

            fraToVoice?.setOnClickListener {
                SponsorVideoHelper.startVideoInvitation(SponsorVideoRequest.SRC_MESSAGE_CONTENT_VOICE_CHAT, userBase, context)
            }
            val imageUrl = userBase?.image?.imageUrl
            if (!StringUtils.isEmpty(imageUrl)) {
                YYApplication.getInstance().imageLoader.get(imageUrl,
                        VolleyUtil.getImageListener(headphoto, defaultBitmap, defaultBitmap),
                        headphoto!!.measuredWidth, headphoto!!.measuredHeight, true)
            }
            val nickName = userBase?.nickName
            nickname?.text = nickName
            if (userBase?.age == 0) {
                age?.visibility = View.GONE
            } else {
                age?.visibility = View.VISIBLE
                age?.text = "${userBase?.age.toString()}岁"
            }
//
//            height?.text = userBase?.height + "cm"

            // TODO:auth
//            if ( userBase?.isAuthentication == 1) {
//                ivAuth?.setImageResource(R.drawable.auth_yao)
//                ivAuth?.visibility=View.VISIBLE
//            }else{
//                ivAuth?.setImageResource(R.drawable.auth_default_yao)
//                ivAuth?.visibility=View.VISIBLE
//            }
            var listLabel = videoGirlUser?.listLabel
            when {
                listLabel?.size == 1 -> {
                    hobby?.visibility = View.VISIBLE
                    chracter?.visibility = View.GONE

                    hobby?.text = yyDataPool?.getKvsName(yyDataPool?.character_opposite, listLabel[0])
                }
                listLabel?.size == 2 -> {
                    chracter?.visibility = View.VISIBLE

                    val label = yyDataPool?.getKvsName(yyDataPool?.character_opposite, listLabel[0])
                    if (StringUtils.isEmpty(label)) {
                        hobby?.visibility = View.GONE
                    } else {
                        hobby?.text = label
                        hobby?.visibility = View.VISIBLE
                    }

                    chracter?.text = yyDataPool?.getKvsName(yyDataPool?.interset, listLabel[1])
                }
                else -> {
                    hobby?.visibility = View.INVISIBLE
                    chracter?.visibility = View.GONE
                }
            }

//            //翻牌：标签样式修改
//            when {
//                position % 3 == 0 -> hobby?.setBackgroundResource(R.drawable.bg_round_8_white)
//                position % 3 == 1 -> hobby?.setBackgroundResource(R.drawable.bg_round_8_white)
//                else -> hobby?.setBackgroundResource(R.drawable.bg_round_8_white)
//            }

//            when {
//                userBase?.showVideo == 1 -> {
//                    chracter?.visibility = View.GONE
//                    chatState?.text = "可视频"
//                    chatState?.visibility = View.GONE
//                    chatState?.setTextColor(Color.parseColor("#e08570"))
//                    chatState?.setCompoundDrawablesWithIntrinsicBounds(R.drawable.space_round_video_icon, 0, 0, 0)
//                    chatState?.setBackgroundResource(R.drawable.space_round_video_shape)
//                }
//                userBase?.showVoice == 1 -> {
//                    chracter?.visibility = View.GONE
//                    chatState?.text = "可语音"
//                    chatState?.visibility = View.GONE
//                    chatState?.setTextColor(Color.parseColor("#e77ba9"))
//                    chatState?.setCompoundDrawablesWithIntrinsicBounds(R.drawable.space_round_voice_icon, 0, 0, 0)
//                    chatState?.setBackgroundResource(R.drawable.space_round_voice_shape)
//                }
//                else -> chatState?.visibility = View.GONE
//            }
            // 0-不在线，1-在线，2-空闲中，3-通话中
            when (userBase?.videoOnLine) {
                // 离开
                0 -> {
                    ivOnlineState?.visibility = View.VISIBLE
                    tvOnlineState?.visibility = View.VISIBLE
                    ivOnlineState?.setBackgroundResource(R.drawable.bg_circle_7c7eea)
                    tvOnlineState?.text = "离开"
                    tvOnlineState?.setTextColor(Color.parseColor("#7c7eea"))
                }
                // 在线
                1 -> {
                    ivOnlineState?.visibility = View.VISIBLE
                    tvOnlineState?.visibility = View.VISIBLE
                    ivOnlineState?.setBackgroundResource(R.drawable.bg_circle_fa3680)
                    tvOnlineState?.text = "在线"
                    tvOnlineState?.setTextColor(Color.parseColor("#fa3680"))
                }
                // 空闲
                2 -> {
                    ivOnlineState?.visibility = View.VISIBLE
                    tvOnlineState?.visibility = View.VISIBLE
                    ivOnlineState?.setBackgroundResource(R.drawable.bg_circle_79cd81)
                    tvOnlineState?.text = "空闲"
                    tvOnlineState?.setTextColor(Color.parseColor("#79cd81"))
                }
                // 忙线
                3 -> {
                    ivOnlineState?.visibility = View.VISIBLE
                    tvOnlineState?.visibility = View.VISIBLE
                    ivOnlineState?.setBackgroundResource(R.drawable.bg_circle_fbaa5a)
                    tvOnlineState?.text = "忙线"
                    tvOnlineState?.setTextColor(Color.parseColor("#fbaa5a"))
                }
                else -> {
                    ivOnlineState?.visibility = View.GONE
                    tvOnlineState?.visibility = View.GONE
                }
            }

            if (userBase?.videoOnLine == 1) {
                linOnlineState?.startAnimation(AlphaAnimation(0f, 1f).apply {
                    fillBefore = true
                    repeatCount = AlphaAnimation.INFINITE
                    repeatMode = AlphaAnimation.REVERSE
                    duration = 500
                })
            } else {
                linOnlineState?.clearAnimation()
            }
        }
    }
}
